==> steinbock-0.9.0.tar.gz: steinbock-0.9.0/README.md <==
<img src="docs/img/steinbock-logo.png" align="right" alt="Logo" width="150" />

# steinbock

<a href="https://python.org"><img alt="Python" src="https://img.shields.io/pypi/pyversions/steinbock"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/pkgs/container/steinbock" alt="Build"><img alt="Build" src="https://img.shields.io/github/workflow/status/BodenmillerGroup/steinbock/build?label=build"></a>
<a href="https://pypi.org/project/steinbock" alt="PyPI"><img alt="PyPI" src="https://img.shields.io/pypi/v/steinbock"></a>
<a href="https://codecov.io/gh/BodenmillerGroup/steinbock"><img alt="Coverage" src="https://img.shields.io/codecov/c/github/BodenmillerGroup/steinbock"></a>
<a href="https://bodenmillergroup.github.io/steinbock" alt="Documentation"><img alt="Documentation" src="https://img.shields.io/github/workflow/status/BodenmillerGroup/steinbock/docs?label=docs"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/issues" alt="Issues"><img alt="Issues" src="https://img.shields.io/github/issues/BodenmillerGroup/steinbock"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/pulls" alt="Pull requests"><img alt="Pull requests" src="https://img.shields.io/github/issues-pr/BodenmillerGroup/steinbock"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/blob/main/LICENSE" alt="License"><img alt="License" src="https://img.shields.io/github/license/BodenmillerGroup/steinbock"></a>

Dockerized multi-channel image processing framework

Documentation is available at https://bodenmillergroup.github.io/steinbock

==> steinbock-0.10.2.tar.gz: steinbock-0.10.2/README.md <==
<img src="https://raw.githubusercontent.com/BodenmillerGroup/steinbock/main/docs/img/steinbock-logo.png" align="right" alt="Logo" width="150" />

# steinbock

<a href="https://python.org"><img alt="Python" src="https://img.shields.io/pypi/pyversions/steinbock"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/pkgs/container/steinbock" alt="Build"><img alt="Build" src="https://img.shields.io/github/workflow/status/BodenmillerGroup/steinbock/build?label=build"></a>
<a href="https://pypi.org/project/steinbock" alt="PyPI"><img alt="PyPI" src="https://img.shields.io/pypi/v/steinbock"></a>
<a href="https://codecov.io/gh/BodenmillerGroup/steinbock"><img alt="Coverage" src="https://img.shields.io/codecov/c/github/BodenmillerGroup/steinbock"></a>
<a href="https://bodenmillergroup.github.io/steinbock" alt="Documentation"><img alt="Documentation" src="https://img.shields.io/github/workflow/status/BodenmillerGroup/steinbock/docs?label=docs"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/issues" alt="Issues"><img alt="Issues" src="https://img.shields.io/github/issues/BodenmillerGroup/steinbock"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/pulls" alt="Pull requests"><img alt="Pull requests" src="https://img.shields.io/github/issues-pr/BodenmillerGroup/steinbock"></a>
<a href="https://github.com/BodenmillerGroup/steinbock/blob/main/LICENSE" alt="License"><img alt="License" src="https://img.shields.io/github/license/BodenmillerGroup/steinbock"></a>

Dockerized multi-channel image processing framework

Documentation is available at https://bodenmillergroup.github.io/steinbock
